##  Integration Setup
Is it possible to use the integration for a decoupled method involving an integration layer with a middleware used as a source for communicating updates to downstream platforms such as ServiceNow, instead of a point-to-point approach?
No, the out-of-the-box ServiceNow integration is designed to communicate directly with ServiceNow.
If service management processes generate data that is required in SAP LeanIX, does the integration support receiving updates from ServiceNow or another integration platform linked to a downstream platform?
The integration can fetch data from a ServiceNow CMDB table like cmdb_ci_business_app, including data available directly on the attributes or related attributes using a reference field. For more information, see [Dot Walking](https://help.sap.com/docs/leanix/ea/servicenow-advanced-configuration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275ca2427a441014910284b4a2cfb5b7__dot_walking). Attributes and relationships can be synchronized from ServiceNow to SAP LeanIX. You can synchronize the fields available in a table on the Mappings tab of the integration configuration.
Are there any reporting tools to surface mismatches between attributes in the two systems before you enable the integration?
No, but you can use a cloned sandbox workspace and a non-production ServiceNow instance to test the integration. Additionally, you can set up an integration with Microsoft PowerBI to further extract data and perform analysis. To learn more, see [OData Integration](https://help.sap.com/docs/leanix/ea/odata-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Export fact sheet data into business intelligence tools through OData endpoints.").
Are there any key ServiceNow components, such as ServiceNow HAM Pro or SAM Pro, that are required to enable proper data transfer to SAP LeanIX?
The integration relies on the data available in the Hardware and Software Model table in ServiceNow. Hence, it doesn’t matter how the data is captured as long as it’s accurate.
Is the "ServiceNow ID" field editable in the UI?
The ServiceNow ID field is marked as read-only because it's only used for mapping between SAP LeanIX and ServiceNow. If you want to modify this field, please [submit a ticket![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport "https://www.leanix.net/support") to SAP LeanIX Support. If you're an SAP customer, submit a request from the [SAP for Me![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2F "https://me.sap.com/") portal.
Our organization doesn’t use ServiceNow. How can we set up a ServiceNow native integration?
You can use SAP LeanIX APIs to build a similar integration. For more information, see [SAP LeanIX APIs](https://help.sap.com/docs/leanix/ea/sap-leanix-apis?locale=en-US&state=PRODUCTION&version=CLOUD "Explore SAP LeanIX APIs and learn when to use each API.").
